# eric7.Plugins.VcsPlugins.vcsGit.GitSubmodulesUpdateOptionsDialog

Module implementing a dialog to enter options for a submodule update command.

### Global Attributes

None

### Classes

GitSubmodulesUpdateOptionsDialog | Class implementing a dialog to enter options for a submodule update command.

### Functions

None

## GitSubmodulesUpdateOptionsDialog

Class implementing a dialog to enter options for a submodule update command.

### Derived from

QDialog, Ui_GitSubmodulesUpdateOptionsDialog

### Class Attributes

None

### Class Methods

None

### Methods

GitSubmodulesUpdateOptionsDialog | Constructor
getData | Public method to get the entered data.

### Static Methods

None

#### GitSubmodulesUpdateOptionsDialog (Constructor)

GitSubmodulesUpdateOptionsDialog(submodulePaths, parent=None)

Constructor

submodulePaths (list of str)
  list of submodule paths
parent (QWidget)
  reference to the parent widget

#### GitSubmodulesUpdateOptionsDialog.getData

getData()

Public method to get the entered data.

Return:
  tuple containing the update procedure, a flag indicating an init, a flag indicating an update with remote, a flag indicating not to fetch the remote, a flag indicating an enforced operation and a list of selected submodules.

Return Type:
  tuple of (int, bool, bool, bool, bool, list of str)

Up